@@ -48,7 +48,7 @@ def get_channel(e):
 	return int((e-1.6)/0.04)
 
 def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis.fits', 
-                    in_level_down=0, in_level_up = 1e10, quantile=0.8, make_plot=True, 
+                    in_level_down=0, in_level_up = 1e10, quantile=0.8, plot_file_name=None, 
                     far=1e-4, histo_bins=300, time0=0):
 	"""Creates user GTI based on hisogram of rates
 
@@ -61,7 +61,7 @@ def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis
 		level_down (int, optional): not lower than this. Defaults to 0. 
 		level_up (int, optional): not larger than this. Defaults to 1e10.
 		quantile (float, optional): quantile to fit the distribution. Defaults to 0.8.
-		make_plot (bool, optional): if making plots. Defaults to True.
+		plot_file_name (str, optional): if making plots. Defaults to None (no plot).
 		far (_type_, optional): the False Alarm Rate to exclude intervals from the fitted distribution. Defaults to 1e-4.
 		histo_bins (int, optional): number of bins in the histogram. Defaults to 300.
 		time0: a time to add to GTI times to be consistnt with observations
@@ -74,6 +74,9 @@ def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis
 	from astropy.io import fits as pf
 	from . import utils
 
+	if plot_file_name is None:
+		make_plot=False
+
 	if lognormal:
 		rate = np.log10(in_rate)
 		drate = in_drate/in_rate
@@ -87,7 +90,7 @@ def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis
 		level_down = in_level_down
 		level_up = in_level_up
 
-	limit_down, limit_up = utils.rate_filter(time, rate, drate, 
+	limit_down, limit_up, fig = utils.rate_filter(time, rate, drate, 
                                        level_down=level_down, 
                                        level_up = level_up, 
                                        quantile=quantile, 
@@ -96,6 +99,16 @@ def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis
     
 	new_gti = create_gti_from_condition(time, (rate > limit_down) & (rate < limit_up) )
 
+	if make_plot:
+		ax = fig.axes[0]
+		start=new_gti[:,0]
+		stop=new_gti[:,1]
+		ax.axvspan(time[0], start[0], alpha=0.5, color='yellow')
+		for ini, fin in zip(stop[0:-1], start[1:]):
+			ax.axvspan(ini, fin, alpha=0.5, color='yellow')
+		ax.axvspan(stop[-1], time[-1], alpha=0.5, color='yellow')
+		fig.savefig(plot_file_name)
+
 	if len(new_gti.shape)>1:
 		start=new_gti[:,0]+time0
 		stop=new_gti[:,1]+time0
@@ -105,6 +118,7 @@ def create_user_gti(time, in_rate, in_drate, lognormal=True, gti_name='user_gtis
 		tbhdu = pf.BinTableHDU.from_columns(coldefs)
 		tbhdu.header['EXTNAME']='GTI'
 		tbhdu.writeto(gti_name, overwrite=True)
+		logger.info('Written %s on disk' % gti_name)
 	else:
 		logger.warning('No GTI file written, as no GTIs are present')
     
