@@ -307,6 +307,7 @@ y
 
 
 xselect_gti_filter='''dummy
+
 read eve %s
 
 
@@ -314,6 +315,8 @@ filter time file %s
 extract events
 save events %s
 yes
+
+
 quit
 no
 
@@ -346,6 +349,7 @@ def make_enphase(freq,  min_en=3., max_en=70., en_step=0.5, n_bins=32, orbitfile
                 if user_gti is not None:
                     with open('gti_select_cmd.txt', 'w') as f2:
                         f2.write(xselect_gti_filter %('%s%s.evt' % (tt, unit), user_gti, '%s%s_filtered.evt' % (tt, unit) ))
+                    run('rm -f %s%s_filtered.evt' % (tt, unit))
                     run('xselect < gti_select_cmd.txt')
                     ff.write('%s%s_filtered.evt' % (tt, unit) )
                 else:
@@ -647,6 +651,7 @@ def make_tphase(freq,  min_en=3., max_en=70., t_step=1000, n_bins=32, orbitfile=
                 if user_gti is not None:
                     with open('gti_select_cmd.txt', 'w') as f2:
                         f2.write(xselect_gti_filter %('%s%s.evt' % (tt, unit), user_gti, '%s%s_filtered.evt' % (tt, unit) ))
+                    run('rm -f %s%s_filtered.evt' % (tt, unit))
                     run('xselect < gti_select_cmd.txt')
                     ff.write('%s%s_filtered.evt' % (tt, unit) )
                 else:
@@ -1584,15 +1589,18 @@ def plot_matrix_as_lines(t, pp, dpp, kind='T', normalize=False, offset=0):
     #plt.legend()
 
 def get_fourier_coeff(pulse, n=2):
-    '''
-    returns the first two harmonic coefficients
-    :param pulse:
-    :return:
-    phi0 phase of first harmonic
-    phi0_2 phase of second harmonic
-    a relative amplitude of first harmonic
-    a2 relative amplitude of second harmonic
-    '''
+    """returns the first n Fourier coefficients in polar form
+
+    Args:
+        pulse (array): the pulse profile
+        n (int, optional): number of harmonics. Defaults to 2.
+
+    Raises:
+        IndexError: if n is larger than len(pulse/2)
+
+    Returns:
+       a, phi: numpy arrays: amplitudes and phases of the first n Fourier coefficients
+    """
 
     # phi = np.linspace(0, 2 * np.pi, len(pulse))
     # i_c = np.sum(np.cos(phi) * pulse) / np.pi
@@ -1646,10 +1654,12 @@ This is useful if one want to eliminate a peculiar part of an observation.
 The filter is controlled in the following way:
 - a Gaussian is fitted on LC data within the innner quantile (default=0.8) of the light curve
 - a limit is set on FAR, but it can be overrided by using the level_up and level_down parameters, which are the lowest/highest possible limit.
+It returns the limits and a handle to the figure (or None)
         '''
         
     print(rate_filter.__doc__)
 
+    f = None
     if make_plot:
         f, axes = plt.subplots(1, 2)
         axes[0].errorbar(time, rate, yerr=drate, linestyle='none')
@@ -1679,8 +1689,8 @@ The filter is controlled in the following way:
         _ = axes[1].axvline(limit_down, 0, 1, color='blue')
         _ = axes[0].axhline(limit_down, 0, 1, color='blue')
         
-        plt.savefig('rate_select.pdf')
-    return limit_down, limit_up
+        
+    return limit_down, limit_up, f
 
 def write_orbit_file_from_gbm_page(url, file_name='orbit.dat',
                                    orbital_parameters = ['axsin', 'Eccentricity', 'periastron',
